Removal of deprecated API ``@numba.generated_jit``.
===================================================

As per the deprecation schedule for 0.59.0, support for
``@numba.generated_jit`` has been removed. Use of ``@numba.extending.overload``
and the high-level extension API is recommended as a replacement.
